@@ -395,7 +395,7 @@ class showGPX(ranaModule):
     self.set('num_updates', self.get('num_updates', 0) + 1)
     #print "Updated %d times" % (self.get('num_updates'))
 
-  def handleMessage(self, message):
+  def handleMessage(self, message, type, args):
     if message == "toggleVisible":
       path = self.getActiveTracklogPath()
       if self.isVisible(path):
